@@ -7,9 +7,12 @@ from .item import Item
 
 class Component:
     def __init__(self, items: Optional[List[Union[Item, List[Item]]]] = None) -> None:
-        self.items = items
+        self.items: List[Union[Item, List[Item]]] = [] if items is None else items
+
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, Component):
+            return NotImplemented
 
-    def __eq__(self, other: 'Component'):
         return self.items == other.items
 
     def make_view(self) -> ui.View:
@@ -20,7 +23,7 @@ class Component:
                 view.add_item(item.to_discord())
                 continue
             for item_ in item:  # type: Item
-                item_._group = i
+                setattr(item_, "_row", i)
                 view.add_item(item_.to_discord())
             i += 1
         return view
